# Lektor minify html

Use [minify-html](https://github.com/wilsonzlin/minify-html), a Rust HTML minifier meticulously optimised for speed and effectiveness, with Lektor.

### Installation

Use the plugins add command

```bash
  lektor plugins add lektor-minify-html
```

> For more information, see the [Lektor plugins documentation](https://www.getlektor.com/docs/plugins/)

### Reference

For information about what minify-html does, refer to its [documentation](https://github.com/wilsonzlin/minify-html).

### License

This project is distributed under the MIT License. See the [LICENSE](https://github.com/seralot/lektor-minify-html/blob/main/LICENSE) file in the repository for more details.
